==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/GetProjectPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property groupName Name of the resource group
 * @property projectName Name of the project
 * @property serviceName Name of the service
 */
public data class GetProjectPlainArgs(
    public val groupName: String,
    public val projectName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs =
        com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs.builder()
            .groupName(groupName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetProjectPlainArgs].
 */
@PulumiTagMarker
public class GetProjectPlainArgsBuilder internal constructor() {
    private var groupName: String? = null

    private var projectName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Name of the resource group
     */
    @JvmName("ovxtqlpylheohtku")
    public suspend fun groupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groupName = mapped
    }

    /**
     * @param value Name of the project
     */
    @JvmName("umfskdbnuylgkihs")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value Name of the service
     */
    @JvmName("gartaonqjnhxgnwv")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetProjectPlainArgs = GetProjectPlainArgs(
        groupName = groupName ?: throw PulumiNullFieldException("groupName"),
        projectName = projectName ?: throw PulumiNullFieldException("projectName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/GetProjectPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property groupName Name of the resource group
 * @property projectName Name of the project
 * @property serviceName Name of the service
 */
public data class GetProjectPlainArgs(
    public val groupName: String,
    public val projectName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs =
        com.pulumi.azurenative.datamigration.inputs.GetProjectPlainArgs.builder()
            .groupName(groupName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetProjectPlainArgs].
 */
@PulumiTagMarker
public class GetProjectPlainArgsBuilder internal constructor() {
    private var groupName: String? = null

    private var projectName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Name of the resource group
     */
    @JvmName("bhmxvxjdxinkijdu")
    public suspend fun groupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.groupName = mapped
    }

    /**
     * @param value Name of the project
     */
    @JvmName("pbfyfspqmywnudwr")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value Name of the service
     */
    @JvmName("waasyifpfkyhmvky")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetProjectPlainArgs = GetProjectPlainArgs(
        groupName = groupName ?: throw PulumiNullFieldException("groupName"),
        projectName = projectName ?: throw PulumiNullFieldException("projectName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}
